package org.mmga.clubs.service;

import org.mmga.clubs.dao.ClubDao;
import org.mmga.clubs.dao.ClubUserAuthDao;
import org.mmga.clubs.entities.BaseResponse;
import org.mmga.clubs.entities.ClubUserAuthVo;
import org.mmga.clubs.entities.auth.Auth;
import org.mmga.clubs.entities.club.Club;
import org.mmga.clubs.entities.club.ClubInformation;
import org.mmga.clubs.entities.club.ClubVo;
import org.mmga.clubs.entities.user.ClubUserSimpleInformation;
import org.mmga.clubs.entities.user.UserSimpleInformation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ClubService {
    private final ClubUserAuthDao clubUserAuthDao;
    private final ClubDao clubDao;
    private final AuthService authService;
    private final UserService userService;

    @Autowired
    public ClubService(ClubUserAuthDao clubUserAuthDao, ClubDao clubDao, AuthService authService, @Lazy UserService userService){
        this.clubDao = clubDao;
        this.clubUserAuthDao = clubUserAuthDao;
        this.authService = authService;
        this.userService = userService;
    }
    public Club getClubWithoutAuthById(int id){
        ClubVo clubById = this.clubDao.getClubById(id);
        if (clubById == null){
            return null;
        }
        Club club = new Club();
        club.setId(id);
        club.setName(clubById.name());
        club.setCommit(clubById.commit());
        return club;
    }
    public Club getClubByUserId(int userId){
        ClubUserAuthVo clubUserAuthVoByUserId = this.clubUserAuthDao.getClubUserAuthVoByUserId(userId);
        if (clubUserAuthVoByUserId == null){
            return null;
        }
        int i = clubUserAuthVoByUserId.authId();
        Auth auth = i != -1 ? authService.getAuthById(i) : null;
        Club clubById = getClubWithoutAuthById(clubUserAuthVoByUserId.clubId());
        clubById.setAuth(auth);
        return clubById;
    }
    private List<ClubUserSimpleInformation> getUserInformationByClubId(int clubId){
        List<ClubUserAuthVo> usersByClubId = this.clubUserAuthDao.getUsersByClubId(clubId);
        return usersByClubId.stream().map(this::packageInformation).toList();
    }
    private ClubUserSimpleInformation packageInformation(ClubUserAuthVo clubUserAuthVo){
        int i = clubUserAuthVo.authId();
        String authName = i != -1 ? authService.getAuthById(i).getName() : "社员";
        UserSimpleInformation userSimpleInformation = userService.getUserSimpleInformation(clubUserAuthVo.userId());
        ClubUserSimpleInformation clubUserSimpleInformation = new ClubUserSimpleInformation();
        clubUserSimpleInformation.setId(userSimpleInformation.getId());
        clubUserSimpleInformation.setName(userSimpleInformation.getName());
        clubUserSimpleInformation.setAvatar(userSimpleInformation.getAvatar());
        clubUserSimpleInformation.setClubId(clubUserAuthVo.clubId());
        clubUserSimpleInformation.setClubAuthName(authName);
        return clubUserSimpleInformation;
    }
    public BaseResponse<ClubInformation> getClubInformationById(int clubId) {
        Club clubWithoutAuthById = getClubWithoutAuthById(clubId);
        ClubInformation clubInformation = new ClubInformation();
        clubInformation.setId(clubWithoutAuthById.getId());
        clubInformation.setName(clubWithoutAuthById.getName());
        clubInformation.setCommit(clubWithoutAuthById.getCommit());
        clubInformation.setUsers(this.getUserInformationByClubId(clubId));
        return BaseResponse.success(clubInformation);
    }
}
